# BoosterPackMaker.py
#
# This is the UI/Front-end code; processing functions are in PackGenerator.py

# This has to do with Magic the Gathering...
#
# Magic cards are distributed by the original manufacturer (Wizards of the Coast) largely in 'booster packs'.
# Booster packs are an assortment of X cards from a set, with a certain amount of cards in each rarity level.
#
# (Rare, Uncommon, Common, BasicLand)
# Rares are generally more powerful than uncommons, uncommons generally more powerful than commons
# BasicLand is a special type of card.
#
# Current boosters have 15 cards: 1 rare, 3 uncommon, 10 common, 1 basic land.
#
# This program is designed to 'look at' text files premade for that set - one list for each rarity in the set.
# Each list is a text file that has the names of all the cards in the set at that rarity
#
# Having that information, it will use randomness to generate a 'booster pack'.
# FYI, Python's 'random' module is based off the Mersenne Twister Pseudo-Random Number Generator (PRNG)

import random
from PackGenerator import TwoList_PackChooser
from PackGenerator import ThreeList_PackChooser
from PackGenerator import FourList_PackChooser
from PackGenerator import FiveList_PackChooser
from PackGenerator import SixList_PackChooser
from word_wrap import wrap # this function helps format the text-block messages that are displayed on the screen.

MTG_description = """
Magic the Gathering, a trading card game published by Wizards of the Coast. \
The cards carry a fantasy theme, but there is a majot aspect of strategy in deciding what cards to put in a deck, \
and how to play them out during a game. \
The cards are distributed by WotC mainly in booster packs - \
15 cards that are randomized according to certain rules, and sealed in a foil wrapper. \
"""

BPM_program_description = """
This program first asks the user what set he/she wants to simulate a boooster pack of. \
This choice is represented by a number. \
The program then ties that number to the appropriate set. \
For each number, the program loads up the rules by which that's set's packs are assembled. \
Making a random choice from lists representing the cards that are in that set, \
the displayed result simulates what could be in a booster pack of that set. \
 \
This does not take print runs into account - yet. \
("Print runs" are how WotC arranges cards on the printing sheets. \
This keeps packs from being wholly random, but acocunting for print runs brings you somewhat \
closer to the actual composition of packs.) \
I believe that this program provides a solid approximation, though.
"""

print "Do you want to see a quick description of the MTG card game, and what this program does that's related to it?"

see_descriptions_prompt = raw_input("Y or N?")

if see_descriptions_prompt.upper() == "Y": # upper() code clears up capiltalization error(s) in what the user enters
    print wrap(MTG_description, 70)
    print
    print wrap(BPM_program_description, 70)

print ""
print "Do you want to see the list of sets that this program is capable of working with?"
print "This will also show the set codes that I used, and which you'll need to type in to select that set."
print "If you know the set code you want to use, you can skip this step."
print ""

see_codes_prompt = raw_input("Y or N?")

if see_codes_prompt.upper() == "Y":

    print
    print "This program has been set up to work with each of the following sets:"
    
    print "Set Code AN - Arabian Nights (Non-block expansion), WOTC/Richard Garfield, 1993"
    print "Set Code Ravnica - Ravnica: City of Guilds (1st set in Ravnica Block), WOTC, 2005"
    print "Set Code Guildpact - Guildpact (2nd set in Ravnica Block), WOTC, 2006"
    print "Set Code Dissension - Dissension (3rd set in Ravnica Block), WOTC, 2006"
    print "Set Code 0 - UnStable , self-designed Un-Set, Alan Gilfoy, 2007-2008"
    print "Set Code 42 - 42nd Edition, self-complied Core Set, Alan Gilfoy, 2007-2008"
    print "Set Code Revolution - Tal Nazarem: Revolution, self-designed set, Alan Gilfoy, 2008"
    print
        
make_a_pack = True
while make_a_pack:

    print "Would you like to generate an MTG booster pack now, or generate another one?"
    AnotherPack = raw_input("Y (for Yes) or N? (for no)")

    if AnotherPack.upper() == "Y":

        set_choice = raw_input("What set do you want to generate a booster pack for? Enter its set code, without spaces.")

        # Congratulations, here's the program's Easter Egg
        if set_choice.lower() == "test":
            # 'test' is not displayed on the list of set codes, but still works

            C_list = open("test_Commons.txt").readlines()
            UC_list = open("test_Uncommons.txt").readlines()
            R_list = open("test_Rares.txt").readlines()
            BL_list = open("test_BasicLand.txt").readlines()
            SpecialA_list = open("test_Tokens.txt").readlines()
            SpecialB_list = open("test_Power.txt").readlines()

            C = 11
            UC = 3
            R = 1
            BL = 1
            SA = 1
            SB = 1

            SixList_PackChooser(C_list, UC_list, R_list, BL_list, SpecialA_list, SpecialB_list, C, UC, R, BL, SA, SB)

            # In this case, SpecialA represents some classic creature tokens and SpecialB is a list of the Power Nine.

        if set_choice.upper() == "AN":

            C_list = open("ArabianNights_Commons.txt").readlines()
            UC_list = open("ArabianNights_Uncommons.txt").readlines()

            C = 6
            UC = 2

            TwoList_PackChooser(C_list, UC_list, C, UC)

        if set_choice == "Ravnica":

            C_list = open("Ravnica_Commons.txt").readlines()
            UC_list = open("Ravnica_Uncommons.txt").readlines()
            R_list = open("Ravnica_Rares.txt").readlines()

            C = 11
            UC = 3
            R = 1

            ThreeList_PackChooser(C_list, UC_list, R_list, C, UC, R)

        if set_choice == "Guildpact":

            C_list = open("Guildpact_Commons.txt").readlines()
            UC_list = open("Guildpact_Uncommons.txt").readlines()
            R_list = open("Guildpact_Rares.txt").readlines()

            C = 11
            UC = 3
            R = 1

            ThreeList_PackChooser(C_list, UC_list, R_list, C, UC, R)

        if set_choice == "Dissension":
            
            C_list = open("Dissension_Commons.txt").readlines()
            UC_list = open("Dissension_Uncommons.txt").readlines()
            R_list = open("Dissension_Rares.txt").readlines()

            C = 11
            UC = 3
            R = 1

            ThreeList_PackChooser(C_list, UC_list, R_list, C, UC, R)

        if set_choice == "0":

            C_list = open("UnStable_Commons.txt").readlines()
            UC_list = open("UnStable_Uncommons.txt").readlines()
            R_list = open("UnStable_Rares.txt").readlines()
            BL_list = open("UnStable_BasicLands.txt").readlines()
            SpecialA_list = open("UnStable_Tokens.txt").readlines()

            C = 10
            UC = 3
            R = 1
            BL = 1
            SA = 1
            
            FiveList_PackChooser(C_list, UC_list, R_list, BL_list, SpecialA_list, C, UC, R, BL, SA)

        if set_choice == "42":

            C_list = open("42nd-Edition_Commons.txt").readlines()
            UC_list = open("42nd-Edition_Uncommons.txt").readlines()
            R_list = open("42nd-Edition_Rares.txt").readlines()
            BL_list = open("42nd-Edition_BasicLand.txt").readlines()
            SpecialA_list = open("42nd-Edition_Tokens.txt").readlines()
            
            C = 10
            UC = 3
            R = 1
            BL = 1
            SA = 1

            FiveList_PackChooser(C_list, UC_list, R_list, BL_list, SpecialA_list, C, UC, R, BL, SA)

            # In this case, Special_A represents creature-token cards.

        if set_choice == "Revolution":
            
            C_list = open("TN-Revolution_Commons.txt").readlines()
            UC_list = open("TN-Revolution_Uncommons.txt").readlines()
            R_list = open("TN-Revolution_Rares.txt").readlines()
            BL_list = open("TN-Revolution_BasicLand.txt").readlines()
            SpecialA_list = open("TN-Revolution_Tokens.txt").readlines()

            C = 11
            UC = 3
            R = 1
            BL = 1
            SA = 1

            FiveList_PackChooser(C_list, UC_list, R_list, BL_list, SpecialA_list, C, UC, R, BL, SA)

    if AnotherPack.upper() == "N":
        make_a_pack = False

    else:
        print "Please enter 'Y' or 'N' at the next prompt."

print
raw_input("Thank you for using this program. Hit Enter when ready, and the program will proceed to shut down.")
    
