import random

# The basic process:
# Various functions: TwoList, ThreeList, FourList, FiveList
# Each 'list' represents a rarity level; the number of rarity levels a set has determines what _PackChooser is to be used.
#
# Mythic Rare note: Mythic Rares, for those sets that have them, are grouped on the set's Rares list.
# Two copies of a specific regular rare are printed for every copy of a Mythic Rare.
# WotC has arranged each set's mythic-rare count as follows: 3.5 times as many regular rares as Mythic Rares are in the set.
# There are 3.5 times as many different rares, and the rares ar printed twice as much to begin with. So:
# 7 times as many regular rares as Mythic Rares overall, alternately 7:1 or *1 out of every 8 rares is a Mythic Rare*
#
# User-created sets can have a different regular-rares-in-set to mythics-in-set ratio, thus leading to different frequencies.
#
# The program takes the following as inputs:
#
# Input type A: A list of the cards at a certain rairty level in the set; each list is a plain text file with one card name per line.
# (These are in the same folder as the BoosterPackMaker program itself.)
# These are given to the function as arguments: C_list, UC_list, et cetera.
#
# Input type B: the amount of cards of that rarity in the set.
# These are also given to the function as arguments: C, UC, et cetera.
#
# Special_A and Special_B are available for a Timeshifted subset and a creature-token/rules-card subset, where applicable.

def TwoList_PackChooser(C_list, UC_list, C, UC):

    Common = []
    Uncommon = []
            
    for card in C_list:

        if card == C_list[len(C_list) - 1]:
            Common.append(card)

        else:
            short_length = len(card) - 1
            card = card[0:short_length]
            Common.append(card)

    for card in UC_list:

        if card == UC_list[len(UC_list) - 1]:
            Uncommon.append(card)

        else:
            short_length = len(card) - 1
            card = card[0:short_length]
            Uncommon.append(card)

    print "Your pack's contents are as follows:"
    print

    print "Commons:"   
    for card in random.sample(Common, C):
        print card
    print

    print "Uncommons:"    
    for card in random.sample(Uncommon, UC):
        print card
    print

def ThreeList_PackChooser(C_list, UC_list, R_list, C, UC, R):

    Common = []
    Uncommon = []
    Rare = []
            
    for card in C_list:

        if card == C_list[len(C_list) - 1]:
            Common.append(card)

        else:
            short_length = len(card) - 1
            card = card[0:short_length]
            Common.append(card)

    for card in UC_list:

        if card == UC_list[len(UC_list) - 1]:
            Uncommon.append(card)

        else:
            short_length = len(card) - 1
            card = card[0:short_length]
            Uncommon.append(card)

    for card in R_list:

        if card == R_list[len(R_list) - 1]:
            Rare.append(card)

        else:
            short_length = len(card) - 1
            card = card[0:short_length]
            Rare.append(card)

    print "Your pack is:"
    print

    print "Your commons:"   
    for card in random.sample(Common, C):
        print card
    print

    print "Your uncommons:"    
    for card in random.sample(Uncommon, UC):
        print card
    print

    print "Your rare(s):"
    for card in random.sample(Rare, R):
        print card
    print

def FourList_PackChooser(C_list, UC_list, R_list, BL_list, C, UC, R, BL):

    Common = []
    Uncommon = []
    Rare = []
    BasicLand = []
            
    for card in C_list:

        if card == C_list[len(C_list) - 1]:
            Common.append(card)

        else:
            short_length = len(card) - 1
            card = card[0:short_length]
            Common.append(card)

    for card in UC_list:

        if card == UC_list[len(UC_list) - 1]:
            Uncommon.append(card)

        else:
            short_length = len(card) - 1
            card = card[0:short_length]
            Uncommon.append(card)

    for card in R_list:

        if card == R_list[len(R_list) - 1]:
            Rare.append(card)

        else:
            short_length = len(card) - 1
            card = card[0:short_length]
            Rare.append(card)

    for card in BL_list:

        if card == BL_list[len(BL_list) - 1]: # if card is the last item in BL_list
            BasicLand.append(card)

        else:
            short_length = len(card) - 1
            card = card[0:short_length]
            BasicLand.append(card)

    print "Your pack is:"
    print

    print "Your commons:"   
    for card in random.sample(Common, C):
        print card
    print

    print "Your uncommons:"    
    for card in random.sample(Uncommon, UC):
        print card
    print

    print "Your rare(s):"
    for card in random.sample(Rare, R):
        print card
    print

    print "Your basic land:"
    for card in random.sample(BasicLand, BL):
        print card
    print

def FiveList_PackChooser(C_list, UC_list, R_list, BL_list, SpecialA_list, C, UC, R, BL, SA):

    Common = []
    Uncommon = []
    Rare = []
    BasicLand = []
    SpecialA = []
            
    for card in C_list:

        if card == C_list[len(C_list) - 1]:
            Common.append(card)

        else:
            short_length = len(card) - 1
            card = card[0:short_length]
            Common.append(card)

    for card in UC_list:

        if card == UC_list[len(UC_list) - 1]:
            Uncommon.append(card)

        else:
            short_length = len(card) - 1
            card = card[0:short_length]
            Uncommon.append(card)

    for card in R_list:

        if card == R_list[len(R_list) - 1]:
            Rare.append(card)

        else:
            short_length = len(card) - 1
            card = card[0:short_length]
            Rare.append(card)

    for card in BL_list:

        if card == BL_list[len(BL_list) - 1]: # if card is the last item in BL_list
            BasicLand.append(card)

        else:
            short_length = len(card) - 1
            card = card[0:short_length]
            BasicLand.append(card)

    for card in SpecialA_list:

        if card == SpecialA_list[len(SpecialA_list) - 1]: # if card is the last item in Special_A_list
            SpecialA.append(card)

        else:
            short_length = len(card) - 1
            card = card[0:short_length]
            SpecialA.append(card)

    print "Your pack is:"
    print
    #print "Your commons:"   
    for card in random.sample(Common, C):
        print card
    #print

    #print "Your uncommons:"    
    for card in random.sample(Uncommon, UC):
        print card
    #print

    #print "Your rare(s):"
    for card in random.sample(Rare, R):
        print card
    #print

    #print "Basic land:"
    for card in random.sample(BasicLand, BL):
        print card

    #print "Special-rarity:"
    for card in random.sample(SpecialA, SA):
        print card
    #print


def SixList_PackChooser(C_list, UC_list, R_list, BL_list, SpecialA_list, SpecialB_list, C, UC, R, BL, SA, SB):

    Common = []
    Uncommon = []
    Rare = []
    BasicLand = []
    SpecialA = []
    SpecialB = []
            
    for card in C_list:

        if card == C_list[len(C_list) - 1]:
            Common.append(card)

        else:
            short_length = len(card) - 1
            card = card[0:short_length]
            Common.append(card)

    for card in UC_list:

        if card == UC_list[len(UC_list) - 1]:
            Uncommon.append(card)

        else:
            short_length = len(card) - 1
            card = card[0:short_length]
            Uncommon.append(card)

    for card in R_list:

        if card == R_list[len(R_list) - 1]:
            Rare.append(card)

        else:
            short_length = len(card) - 1
            card = card[0:short_length]
            Rare.append(card)

    for card in BL_list:

        if card == BL_list[len(BL_list) - 1]: # if card is the last item in BL_list
            BasicLand.append(card)

        else:
            short_length = len(card) - 1
            card = card[0:short_length]
            BasicLand.append(card)

    for card in SpecialA_list:

        if card == SpecialA_list[len(SpecialA_list) - 1]: # if card is the last item in BL_list
            SpecialA.append(card)

        else:
            short_length = len(card) - 1
            card = card[0:short_length]
            SpecialA.append(card)

    for card in SpecialB_list:

        if card == SpecialB_list[len(SpecialB_list) - 1]: # if card is the last item in BL_list
            SpecialB.append(card)

        else:
            short_length = len(card) - 1
            card = card[0:short_length]
            SpecialB.append(card)

    print "Your pack is:"
    print

    print "Commons:"   
    for card in random.sample(Common, C):
        print card
    print

    print "Uncommons:"    
    for card in random.sample(Uncommon, UC):
        print card
    print

    print "Rare(s):"
    for card in random.sample(Rare, R):
        print card
    print

    print "Basic land:"
    for card in random.sample(BasicLand, BL):
        print card
    print

    print "Special-rarity A:"
    for card in random.sample(SpecialA, SA):
        print card

    print "Special-rarity B:"
    for card in random.sample(SpecialB, SB):
        print card
    print

if __name__ == '__main__':
    print "This is a module, a bit of code designed to be used by another program."
    print "This particular moduel is designed for BoosterPackMaker.py"
        
    print
